import React from "react";
import styled from "react-emotion";
import Slider from "react-slick";

const Carousel = ({ data: { images } }) => {
	if (!images) return "You must select images to render your image carousel!";

	const settings = {
		arrows: false,
		dots: true
	};

	return (
		<CarouselStyles>
			<Slider {...settings}>
				{images.map(image => (
					<div key={image.name} >
						<img src={image.src} alt={image.name} />
					</div>
				))}
			</Slider>
		</CarouselStyles>
	);
};

const CarouselStyles = styled("div")`
	.slick-slide img {
		width: 100%;
	}
	.slick-dots {
		display: flex !important;
		justify-content: center;
		left: 0;
		right: 0;
		transform: none;
		bottom: -50px;
		li {
			margin-left: 7px;
			margin-right: 7px;
			button {
				padding: 0;
				border: none;
				font-size: 0;
				width: 8px;
				height: 8px;
				background: #E5E5E5;
				border-radius: 4px;
				transition: 0.2s width ease-in-out, 0.2s background ease-in-out;
				cursor: pointer;
			}
			&.slick-active {
				button {
					width: 80px;
					background: #B2CE55;
				}
			}
		}
	}
`;

export default Carousel;
